@@ -48,7 +48,7 @@ class ApiClient(QtGui.QWidget):
 
         # other variable 
         self.default_host = 'localhost'
-        self.default_port = '8888'
+        self.default_port = self.VarsGui.Get('core.cl_core_port')
 
         self.client = None
         self.host_name = None
