@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -217,18 +217,8 @@ class ToolGui(QtGui.QWidget):
         self.grid.addWidget(self.h_image_lbl, 0, 0)
         self.grid.addWidget(self.h_image_lineedit, 0, 1)
 
-        # add expers view result in grid
-        self.expert_lbl = LabelWordWrap(_('Expert view'), self)
-        self.expert_checkbox = QtGui.QCheckBox(self)
-        self.expert_checkbox.setChecked(ClientObj.expert)
-        self.expert_lbl.setToolTip(_('View results in expert mode'))
-        self.expert_checkbox.setToolTip(_('View results in expert mode'))
-
-        self.grid.addWidget(self.expert_lbl, 1, 0)
-        self.grid.addWidget(self.expert_checkbox, 1, 1, 1, 2)
-
         # add count item in result table in grid
-        self.count_row_lbl = LabelWordWrap(_('Rows in the Table'),self)
+        self.count_row_lbl = LabelWordWrap(_('Rows in Table'),self)
         self.count_row_lbl.setMaximumWidth \
                                     (self.count_row_lbl.sizeHint().width())
 
@@ -245,7 +235,6 @@ class ToolGui(QtGui.QWidget):
 
         # connect all with change value slot
         self.h_image_lineedit.textChanged.connect(self.changed_val)
-        self.expert_checkbox.clicked.connect(self.changed_val)
         self.count_row_lineedit.textChanged.connect(self.changed_val)
 
     def changed_val(self):
@@ -287,7 +276,6 @@ class ToolGui(QtGui.QWidget):
 
 #            bg_color_flag = False
             count_row_flag = False
-            expert_flag = False
             count_row_flag = False
             h_image_flag = False
 
@@ -301,13 +289,6 @@ class ToolGui(QtGui.QWidget):
                     if height_image < 0 or height_image > 512:
                         height_image = ClientObj.height_image
                     new_config.append('height_image = %d\n' %height_image)
-                elif line.startswith('expert '):
-                    expert_flag = True
-                    if self.expert_checkbox.isChecked():
-                        expert = 1
-                    else:
-                        expert = 0
-                    new_config.append('expert = %d\n' %expert)
                 elif line.startswith('count_row '):
                     count_row_flag = True
                     try:
@@ -320,13 +301,6 @@ class ToolGui(QtGui.QWidget):
                 else:
                     new_config.append(line)
 
-            if self.expert_checkbox.isChecked():
-                expert = 1
-            else:
-                expert = 0
-            new_config = self.check_cfg (expert_flag, new_config, \
-                                '[gui]', 'expert', expert)
-
             try:
                 count_row = int(self.count_row_lineedit.text())
                 if count_row < 2:
@@ -377,7 +351,7 @@ class ToolOther(QtGui.QWidget):
         self.lang_lbl.setMaximumWidth(self.lang_lbl.sizeHint().width())
 
         self.lang_ComboBox = QComboBox(self)
-        lang_dict = {'en': _('English'),'ru': _('Russian')}
+        lang_dict = {'en': _('English'),'ru': _('Russian'),'fr':_('French')}
 
         for lang in lang_dict:
             self.lang_ComboBox.addItem(lang_dict[lang])
@@ -532,4 +506,4 @@ class ToolOther(QtGui.QWidget):
                     if type (ClientObj.MainWidget.MainFrameWgt) \
                                                             == DisplayMethod:
                         ClientObj.MainWidget.display_methods()
-        return wrapper
\ No newline at end of file
+        return wrapper
